@@ -22,10 +22,11 @@ import base64
 
 class Options(object):
 
-    _binary_location = ''
-    _arguments = []
-    _extension_files = []
-    _experimental_options = {}
+    def __init__(self):
+        self._binary_location = ''
+        self._arguments = []
+        self._extension_files = []
+        self._experimental_options = {}
 
     @property
     def binary_location(self):
@@ -71,7 +72,7 @@ class Options(object):
         """
         encoded_extensions = []
         for ext in self._extension_files:
-            file_ = open(ext)
+            file_ = open(ext, 'rb')
             # Should not use base64.encodestring() which inserts newlines every
             # 76 characters (per RFC 1521).  Chromedriver has to remove those
             # unnecessary newlines before decoding, causing performance hit.
@@ -123,7 +124,8 @@ class Options(object):
 
         chrome_options = self.experimental_options.copy()
         chrome_options["extensions"] = self.extensions
-        chrome_options["binary"] = self.binary_location
+        if self.binary_location:
+            chrome_options["binary"] = self.binary_location
         chrome_options["args"] = self.arguments
 
         chrome["chromeOptions"] = chrome_options
